==> pmml-model-1.4.13-sources.jar: org/dmg/pmml/mining/PMMLElements.java <==

package org.dmg.pmml.mining;

import java.lang.reflect.Field;

public interface PMMLElements {

    Field MININGMODEL_EXTENSIONS = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "extensions");
    Field MININGMODEL_MININGSCHEMA = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "miningSchema");
    Field MININGMODEL_OUTPUT = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "output");
    Field MININGMODEL_MODELSTATS = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "modelStats");
    Field MININGMODEL_MODELEXPLANATION = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "modelExplanation");
    Field MININGMODEL_TARGETS = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "targets");
    Field MININGMODEL_LOCALTRANSFORMATIONS = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "localTransformations");
    Field MININGMODEL_EMBEDDEDMODELS = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "embeddedModels");
    Field MININGMODEL_SEGMENTATION = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "segmentation");
    Field MININGMODEL_MODELVERIFICATION = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "modelVerification");
    Field SEGMENT_EXTENSIONS = org.jpmml.model.ReflectionUtil.getField(Segment.class, "extensions");
    Field SEGMENT_PREDICATE = org.jpmml.model.ReflectionUtil.getField(Segment.class, "predicate");
    Field SEGMENT_MODEL = org.jpmml.model.ReflectionUtil.getField(Segment.class, "model");
    Field SEGMENTATION_EXTENSIONS = org.jpmml.model.ReflectionUtil.getField(Segmentation.class, "extensions");
    Field SEGMENTATION_LOCALTRANSFORMATIONS = org.jpmml.model.ReflectionUtil.getField(Segmentation.class, "localTransformations");
    Field SEGMENTATION_SEGMENTS = org.jpmml.model.ReflectionUtil.getField(Segmentation.class, "segments");

}

==> pmml-model-1.5.0-sources.jar: org/dmg/pmml/mining/PMMLElements.java <==

package org.dmg.pmml.mining;

import java.lang.reflect.Field;

public interface PMMLElements {

    Field MININGMODEL_EXTENSIONS = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "extensions");
    Field MININGMODEL_MININGSCHEMA = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "miningSchema");
    Field MININGMODEL_OUTPUT = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "output");
    Field MININGMODEL_MODELSTATS = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "modelStats");
    Field MININGMODEL_MODELEXPLANATION = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "modelExplanation");
    Field MININGMODEL_TARGETS = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "targets");
    Field MININGMODEL_LOCALTRANSFORMATIONS = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "localTransformations");
    Field MININGMODEL_EMBEDDEDMODELS = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "embeddedModels");
    Field MININGMODEL_SEGMENTATION = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "segmentation");
    Field MININGMODEL_MODELVERIFICATION = org.jpmml.model.ReflectionUtil.getField(MiningModel.class, "modelVerification");
    Field SEGMENT_EXTENSIONS = org.jpmml.model.ReflectionUtil.getField(Segment.class, "extensions");
    Field SEGMENT_PREDICATE = org.jpmml.model.ReflectionUtil.getField(Segment.class, "predicate");
    Field SEGMENT_MODEL = org.jpmml.model.ReflectionUtil.getField(Segment.class, "model");
    Field SEGMENT_VARIABLEWEIGHT = org.jpmml.model.ReflectionUtil.getField(Segment.class, "variableWeight");
    Field SEGMENTATION_EXTENSIONS = org.jpmml.model.ReflectionUtil.getField(Segmentation.class, "extensions");
    Field SEGMENTATION_LOCALTRANSFORMATIONS = org.jpmml.model.ReflectionUtil.getField(Segmentation.class, "localTransformations");
    Field SEGMENTATION_SEGMENTS = org.jpmml.model.ReflectionUtil.getField(Segmentation.class, "segments");

}
